Names provided in a character vector will be compared with names stored in
slot taxonNames of an object of class taxlist by using the
function stringdist::stringsim().
This method is applied to the slot species in the input vegtable
object.
# S4 method for character,vegtable
match_names(x, object, ...)A character vector with names to be compared.
An object of class vegtable to be compared with.
Further arguments passed to taxlist::match_names().
Miguel Alvarez kamapu78@gmail.com
taxlist::match_names() stringdist::stringsim()