Addition of plot observations into existing data sets may implicate merging data
frames with '>vegtable objects.
# S4 method for vegtable,data.frame
add_releves(vegtable, releves, header,
abundance, split_string, usage_ids=FALSE, layers=FALSE, layers_var,
format="crosstable", ...)A data frame including plot observations to be added into
'vegtable'.
A data frame (optional) including header information for plots.
A character value (or vector of length 2) indicating the names
of abundance variable in 'vegtable'.
Character value used to split mixed abundance codes.
Logical value indicating whether species are as taxon usage ids
(integers) or names in 'releves'.
Logical value indicating whether layers are included in
'releves' or not.
Name of the layer variable in 'vegtable'.
Character value indicating input format of 'releves'
(whether 'crosstable' or 'databaselist').
Further arguments passed to function cross2db
(i.e. 'na_strings').
Since this function will only update slots 'samples' and 'header',
consistency with slots 'layers', 'relations' and 'species'
have to be checked and accordingly updated in advance.
# NOT RUN {
## No example at the moment
# }
Run the code above in your browser using DataLab