Import function for ‘Turboveg’ databases into an object of class
'>vegtable.
Most of the contents of ‘Turboveg’ databases are included in DBF files and
therefore imported by the function read.dbf.
The automatic setting of database path will be done by the function
tv.home but it can be customised by the argument
'tv_home'.
The species list will be imported by using the function
tv2taxlist and therefore formatted as a
'>taxlist object.
Similarly, conversion tables will be handled as
'>coverconvert objects.
Empty columns in the header will be deleted in the imported object.